==> create-node-react-app-1.0.13.tgz: package/my-app/api/index.ts <==
import 'reflect-metadata'
import 'dotenv/config'
import app from '../src/server/initApp'
import '../server/initDatabaseClient'
import admin from 'firebase-admin'
import { buildSchemaSync } from 'type-graphql'
import * as resolversObj from '../src/resolvers'
import { objectToArray } from '../src/utils'
import { ApolloServer } from 'apollo-server-express'
import { ApolloServerPluginDrainHttpServer } from 'apollo-server-core'
import http from 'http'

// initialize firebase admin
let firebaseAdmin: admin.app.App
try {
  firebaseAdmin = admin.initializeApp({
    credential: admin.credential.cert(JSON.parse(process.env.FIREBASE_ADMIN))
  })
} catch (e) {
  console.error('Error parsing FIREBASE_ADMIN env', e)
}

// schema auth checker
function authChecker(root: { context: { user?: { uid: string } } }) {
  return root.context.user?.uid ? true : false
}

// build schema
const resolvers = objectToArray<Function>(resolversObj) as [Function, ...Function[]]
const schema = buildSchemaSync({ resolvers, authChecker })

// get auth headers from request context and verify token
async function context({ req }: { req: any }) {
  if (req.headers.authorization && req.headers.authorization.indexOf('Bearer ') === 0) {
    try {
      const accessToken = req.headers.authorization.slice(7)
      const user = await firebaseAdmin.auth().verifyIdToken(accessToken)
      return { user }
    } catch (e) {
      console.error('Auth error:', e)
    }
  }
}

// create HTTP server
const httpServer = http.createServer(app)

// init apollo server
const server = new ApolloServer({
  schema,
  context,
  introspection: true,
  plugins: [ApolloServerPluginDrainHttpServer({ httpServer })],
})

// link apollo server with express
server.start().then(() => {
  server.applyMiddleware({ app, path: '/api' })
})

export default httpServer

==> create-node-react-app-1.0.16.tgz: package/my-app/api/index.ts <==
import 'reflect-metadata'
import 'dotenv/config'
import app from '../src/server/initApp'
import '../src/server/initDatabaseClient'
import { buildSchemaSync } from 'type-graphql'
import * as resolversObj from '../src/resolvers'
import { objectToArray } from '../src/utils'
import jwt from 'jsonwebtoken'
import { ApolloServer } from 'apollo-server-express'
import { ApolloServerPluginDrainHttpServer } from 'apollo-server-core'
import http from 'http'

// schema auth checker
function authChecker(root: { context: { user?: { uid: string } } }) {
  return root.context.user?.uid ? true : false
}

// build schema
const resolvers = objectToArray<Function>(resolversObj) as [Function, ...Function[]]
const schema = buildSchemaSync({ resolvers, authChecker })

// get auth headers from request context and verify token
const { AUTH_SECRET } = process.env
async function context({ req }: { req: { headers: { authorization?: string } } }) {
  if (req.headers.authorization && req.headers.authorization.indexOf('Bearer ') === 0) {
    try {
      const accessToken = req.headers.authorization.slice(7)
      const user = jwt.verify(accessToken, AUTH_SECRET)
      return { user }
    } catch (e) {
      console.error('Auth error:', e)
    }
  }
}

// create HTTP server
const httpServer = http.createServer(app)

// init apollo server
const server = new ApolloServer({
  schema,
  context,
  introspection: true,
  plugins: [ApolloServerPluginDrainHttpServer({ httpServer })],
})

// link apollo server with express
server.start().then(() => {
  server.applyMiddleware({ app, path: '/api' })
})

export default httpServer
